@@ -30,6 +30,7 @@ import com.google.gwt.user.client.ui.HTML;
 import com.google.gwt.user.client.ui.HorizontalPanel;
 import com.google.gwt.user.client.ui.Widget;
 import com.sencha.gxt.cell.core.client.form.ComboBoxCell.TriggerAction;
+import com.sencha.gxt.core.client.dom.ScrollSupport.ScrollMode;
 import com.sencha.gxt.core.client.util.Margins;
 import com.sencha.gxt.core.client.util.ToggleGroup;
 import com.sencha.gxt.data.shared.ListStore;
@@ -47,8 +48,8 @@ import com.sencha.gxt.widget.core.client.form.TextField;
 
 /**
  * 
- * @author "Giancarlo Panichi" <a
- *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
+ * @author Giancarlo Panichi
+ *
  * 
  */
 public class ConditionWidget extends SimpleContainer {
@@ -147,10 +148,12 @@ public class ConditionWidget extends SimpleContainer {
 		groupMatch.add(radioAny);
 		groupMatch.setValue(radioAll);
 
-		vert = new VerticalLayoutContainer();
-		// vert.setScrollMode(ScrollMode.AUTO); Set In GXT 3.0.1
-		vert.setAdjustForScroll(true);
 
+		vert = new VerticalLayoutContainer();
+		vert.setScrollMode(ScrollMode.AUTO);// Set In GXT 3.0.1
+		vert.setAdjustForScroll(true);
+		
+		
 		setup();
 
 		baseLayout.add(vert, new VerticalLayoutData(1, 1, new Margins(0)));
@@ -426,7 +429,7 @@ public class ConditionWidget extends SimpleContainer {
 		horiz.add(btnAdd, new BoxLayoutData(new Margins(2, 0, 2, 0)));
 		horiz.add(btnDel, new BoxLayoutData(new Margins(2, 0, 2, 0)));
 
-		vert.add(horiz, new VerticalLayoutData(-1, -1, new Margins(1)));
+		vert.add(horiz, new VerticalLayoutData(1, -1, new Margins(1)));
 
 		addBeforeShowHandler(new BeforeShowEvent.BeforeShowHandler() {
 
@@ -705,7 +708,7 @@ public class ConditionWidget extends SimpleContainer {
 		horiz.add(btnAdd, new BoxLayoutData(new Margins(2, 0, 2, 0)));
 		horiz.add(btnDel, new BoxLayoutData(new Margins(2, 0, 2, 0)));
 
-		vert.add(horiz, new VerticalLayoutData(-1, -1, new Margins(1)));
+		vert.add(horiz, new VerticalLayoutData(1, -1, new Margins(1)));
 
 	}
 
@@ -774,7 +777,7 @@ public class ConditionWidget extends SimpleContainer {
 						secondArg == null ? null : secondArg.getCurrentValue(),
 						comboThreshold.getCurrentValue()==null?null:comboThreshold.getCurrentValue());
 			}
-			readableExpressionList.add(mapOp.getReadableExpression());
+			readableExpressionList.add(expression.getReadableExpression());
 			Log.debug(expression.toString());
 			arguments.add(expression);
 		}
